@@ -4,33 +4,33 @@ data_location = os.path.join(__dir__, "system_verilog")
 src = "https://github.com/openhwgroup/cv32e40s"
 
 # Module version
-version_str = "0.3.0.post392"
-version_tuple = (0, 3, 0, 392)
+version_str = "0.4.0.post262"
+version_tuple = (0, 4, 0, 262)
 try:
     from packaging.version import Version as V
-    pversion = V("0.3.0.post392")
+    pversion = V("0.4.0.post262")
 except ImportError:
     pass
 
 # Data version info
-data_version_str = "0.3.0.post250"
-data_version_tuple = (0, 3, 0, 250)
+data_version_str = "0.4.0.post120"
+data_version_tuple = (0, 4, 0, 120)
 try:
     from packaging.version import Version as V
-    pdata_version = V("0.3.0.post250")
+    pdata_version = V("0.4.0.post120")
 except ImportError:
     pass
-data_git_hash = "9757b4230ba7f1d8e3bc2a47210878090b48974e"
-data_git_describe = "0.3.0-250-g9757b423"
+data_git_hash = "d11f4a036f2e8ed322188b3460ea27f2f228b585"
+data_git_describe = "0.4.0-120-gd11f4a03"
 data_git_msg = """\
-commit 9757b4230ba7f1d8e3bc2a47210878090b48974e
-Merge: 16ddbc77 88db3e77
+commit d11f4a036f2e8ed322188b3460ea27f2f228b585
+Merge: 26b419dc adc412cf
 Author: Arjan Bink <40633348+Silabs-ArjanB@users.noreply.github.com>
-Date:   Thu Jun 2 11:57:44 2022 +0200
+Date:   Fri Jul 15 12:18:13 2022 +0200
 
-    Merge pull request #213 from silabs-oysteink/silabs-oysteink_mcounteren-doc
+    Merge pull request #254 from Silabs-ArjanB/ArjanB_244
     
-    Fixed description of mcounteren as that did not get properly merged in…
+    Fix for PMPADDR
 
 """
 
